Name:           fritzing
Version:        0.9.6
Release:        %mkrel 1
Summary:        Electronic Design Automation software; from prototype to product
Group:  		Sciences/Engineering 
License:        GPLv3+
URL:            http://fritzing.org/
Source0:        https://github.com/fritzing/fritzing-app/releases/%{name}-app-%{version}.tar.xz
BuildRequires:  lib64qt5base5-devel desktop-file-utils boost-devel quazip-devel ImageMagick lib64qt5serialport-devel
BuildRequires:  lib64qt5svg-devel libgit2-devel tar
Requires:		lib64qt5sql5 lib64qt5webkit5 lib64quazip5_1 git yad libgit2
Requires:       qt5-database-plugin-sqlite


%description
Fritzing is an open-source initiative to support designers, artists,
researchers and hobbyists to take the step from physical prototyping
to actual product. It is in the spirit of Processing and Arduino which
allows users to document their Arduino and other electronic-based 
prototypes, and to create a PCB layout for manufacturing.

%prep
%setup -q -n %{name}-app-%{version}
%apply_patches

%build
# Use our own libgit2
sed -i 's|LIBGIT_STATIC = true|LIBGIT_STATIC = false|' phoenix.pro

CXXFLAGS="%{optflags}"
%qmake_qt5 
%make

%install
# Clean
rm -rf %{buildroot}

make install INSTALL_ROOT=%{buildroot}

# A few files in /usr/share/fritzing end up executable.
find %{buildroot}%{_datadir}/%{name} -type f -exec %{__chmod} 644 {} \;
find %{buildroot}%{_datadir}/%{name} -type d -exec %{__chmod} 755 {} \;


# Fritzing are not clear about location of parts. Need to fix it with a wrapper
mv %{buildroot}/usr/bin/Fritzing %{buildroot}/usr/bin/Fritzing-org

# If user folder with parts are nonexisting, use git to clone from github
# Then start Fritzing so it knows where the parts are
%__cat > %{buildroot}/usr/bin/Fritzing << EOF
#!/bin/bash
if [ ! -d "\$HOME/fritzing/fritzing-parts" ]; then
    yad --title="Getting Fritzing parts from git" --width=300  --button="OK:0"  --text="Cloning Fritzing parts to:\n\n \$HOME/fritzing/fritzing-parts\n\n Please wait (can take long time) until Fritzing starts"
    git clone https://github.com/fritzing/fritzing-parts.git "\$HOME/fritzing/fritzing-parts"
    pushd "\$HOME/fritzing/fritzing-parts"
    git checkout master
    popd
    /usr/bin/Fritzing-org --database "\$HOME/fritzing/parts.db" --parts "\$HOME/fritzing/fritzing-parts" --folder "%{_datadir}/%{name}"
fi

/usr/bin/Fritzing-org --parts "\$HOME/fritzing/fritzing-parts" --folder "%{_datadir}/%{name}" "$@"
EOF
chmod +x %{buildroot}/usr/bin/Fritzing

# icons
mkdir -p %{buildroot}%{_iconsdir}/hicolor/{16x16,22x22,32x32,48x48,64x64,128x128}/apps
for i in 16 22 32 48 64 128; do \
convert -resize $i\x$i resources/images/fritzing_icon.png %{buildroot}%{_iconsdir}/hicolor/$i\x$i/apps/%{name}.png
done

# Copy 48X48 icon as main icon
cp %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png %{buildroot}%{_iconsdir}/

# Mime type
%__install -dm 755 %{buildroot}%{_datadir}/mime/packages
cat > %{buildroot}%{_datadir}/mime/packages/%{name}.xml << EOF
<?xml version="1.0"?>
<mime-info xmlns='http://www.freedesktop.org/standards/shared-mime-info'>
  <mime-type type="application/x-%{name}">
    <comment>Fritzing file type</comment>
    <glob pattern="*.fzz"/>
  </mime-type>
</mime-info>
EOF


%post
xdg-mime install --mode system --novendor %{_datadir}/mime/packages/%{name}.xml
xdg-mime default %{name}.desktop application/x-%{name}
gio mime application/x-fritzing fritzing.desktop > /dev/null 2>&1
# Application Icon
xdg-icon-resource install --mode "system" --novendor --size 48 %{_iconsdir}/%{name}.png

# Mime type icon
for i in 16 22 32 48 64 128; do \
xdg-icon-resource install --mode "system" --novendor --context mimetypes --size $i %{_iconsdir}/hicolor/$i\x$i/apps/%{name}.png application-x-%{name}
done
%update_icon_cache hicolor
update-mime-database /usr/share/mime
update-desktop-database /usr/share/applications

%postun
xdg-mime uninstall %{_datadir}/mime/application/x-%{name}.xml
for i in 16 22 32 48 64 128; do \
xdg-icon-resource uninstall --context mimetypes --size $i application-x-%{name}
done
%clean_icon_cache hicolor
update-mime-database /usr/share/mime
update-desktop-database /usr/share/applications


%files
%defattr(-,root,root,-)
%{_bindir}
%{_datadir}

%changelog
* Sun May 09 2021 tex - 0.9.6-1pclos2021
- new version

* Sun Dec 27 2020 tex - 0.9.4-3pclos2020
- add quazip5 patch and requires

* Wed Apr 25 2020 MBantz <martin dot bantz at gmail dot com> 0.9.4-2pclos2020
- Missed the shebang in the Fritzing wrapper script

